#!/bin/sh 
#/**********************************************************************
# *                 III TTTTTTT U     U                                *
# *                  I     T    U     U                                *
# *                  I     T    U     U                                *
# *                  I     T    U     U                                *
# *                 III    T    UUUUUUU                                *
# *                                                                    *
# *  ITU Informatics Institute                                         *
# *  Computational Science & Engineering Dept.                         *
# *  Istanbul / TURKIYE                                                *
# *                                                                    *
# *  By: Ozden AKINCI                                                  *
# *  E-mail: akinci@be.itu.edu.tr                                      *
# *  Date: 21.11.2005                                                  *
# *                                                                    *
# *  Associated files :                                                *
# *       > JDL File  : interactive.jdl                                *
# *       > Script    : scriptint.sh                                   *
# *       > InputFile : int01.tar                                      *
# *       > OutputFile:                                                *
# *                                                                    *
#**********************************************************************/

if [ $# -lt 2 ]
then
    echo "usage: `basename $0` <FILE> <HOSTPORT>"
    exit 1
fi

# $1 argument must be with out extension, the argument will refer to
# the <FILE>.tar
FILE=$1

# HOSTPORT will be used to get GUI.
export HOSTPORT=$2

#set DISPLAY environment where you want to get GUI
export DISPLAY=193.206.208.9:0.0


# TARFILE is name of the $1 argument with .tar extension.
# Name of TARFILE must be same with the filename 
# in the InputSandbox attribute of jdl file.
TARFILE=$FILE.tar

# ROOT is the name of the root directory in the tar file.
# File hierarchy is as $FILE/$ROOT
#ROOT=icoFoam

# CASE is the name of the case in the ROOT directory. 
# CASE is also a directory.
# The file hierarchy is as $FILE/$ROOT/$CASE
#CASE=cavity

# OpenFOAM settings 
# The line below is necessary to run an OpenFOAM job.
#################################################
. /opt/OpenFOAM/OpenFOAM-1.2/.OpenFOAM-1.2/bashrc

export RUN=`pwd`
export FOAM_RUN=$RUN/$FILE
export TUTORIALS=${FOAM_RUN}/tutorials
if [ -d $FILE ]
then
    echo "The $FILE directory is available" 
    rm -rf $FILE
fi    
echo "Untaring $TARFILE"
tar xf $TARFILE
RESULT=$?
while [ $RESULT -eq 0 ]
do
    FoamX >/dev/null 
    echo "Do you want to visualize the output (y/n) [N]:"
    read ANS
    case $ANS in
        Y|y) 
             echo ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>"
             echo -e "\n Give the ROOT (e.g. icoFoam):"
             read ROOT
         
             while  [ ! -d $TUTORIALS/$ROOT ] 
             do
                 if [ $ROOT == "quit" -o $ROOT == "exit" ]
                 then
                     break
                 else
                     echo "$ROOT does not exist." 
                     echo " List of the ROOTs"
                     echo ">>>>>>>>>>>>>>>>>>"
                     /bin/ls $TUTORIALS
                     echo "<<<<<<<<<<<<<<<<<<"
                     echo -e "\n Give the ROOT (or quit, exit) :"
                     read ROOT
                 fi
             done
             echo "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<"
             echo "ROOT:$ROOT"
             echo ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>"
             echo -e "\n Give the CASE (e.g. cavity):"
             read CASE
             while  [ ! -d $TUTORIALS/$ROOT/$CASE ] 
             do
                 if [ $CASE == "quit" -o $CASE == "exit" ]
                 then
                     break
                 else
                     echo "$CASE does not exist." 1>&2
                     echo " List of the CASEs"
                     echo ">>>>>>>>>>>>>>>>>>"
                     /bin/ls $TUTORIALS/$ROOT
                     echo "<<<<<<<<<<<<<<<<<<"
                     echo -e "\n Give the CASE (or quit, exit ):"
                     read CASE
                 fi
             done
         
             echo "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<"
             echo "CASE:$CASE"
             paraFoam $TUTORIALS/$ROOT $CASE >/dev/null ;;
        *) ;;
    esac
    
    echo "Do you want to run FoamX again (y/n) [N]:"
    read ANS
    case $ANS in
        Y|y) RESULT=0 ;;
        *) RESULT=1 ;;
    esac
done
#tar cvf $OUTPUTTAR $FILE
