#include <iostream>
#include <string>

#include "glite/lb/JobStatus.h"
#include "glite/wmsutils/exception/Exception.h"
#include "glite/wms/jdl/JobAd.h"
#include "glite/wmsui/api/Job.h"


using namespace std ;
using namespace glite::wms::common::utilities;
using namespace glite::wmsutils::jobid;
using namespace glite::wms::jdl;
using namespace glite::wmsui::api;
using namespace glite::lb;

void printStatus(JobStatus &stat) {
  std::vector<pair<JobStatus::Attr, JobStatus::AttrType> > attrList = stat.getAttrs();

  for (unsigned i=0; i < attrList.size(); i++ ) {
    cout << stat.getAttrName(attrList[i].first) << " == " ;
    
    switch (attrList[i].second) {
    case JobStatus::INT_T     :
      cout << stat.getValInt(attrList[i].first) << endl<<flush;
      break;
    case JobStatus::STRING_T  :
      cout << stat.getValString(attrList[i].first) << endl<<flush;
      break;
    case JobStatus::TIMEVAL_T    :{
      timeval t = stat.getValTime(attrList[i].first);
      cout << t.tv_sec << "." << t.tv_usec << " s " << endl<<flush;}
      break;
    case JobStatus::BOOL_T    :
      cout << stat.getValBool(attrList[i].first) << endl<<flush;
      break;
    case JobStatus::JOBID_T    :{
      if(((JobId)stat.getValJobId(attrList[i].first)).isSet())
	cout << stat.getValJobId(attrList[i].first).toString() << endl<<flush;
    }
      break;
    case JobStatus::STSLIST_T    :{
      std::vector<JobStatus> v = stat.getValJobStatusList(attrList[i].first);
      for(unsigned int i=0; i < v.size(); i++) ; //TBD
    }
      break ;
    case JobStatus::TAGLIST_T :{
      std::vector<std::pair<std::string,std::string> >  v = stat.getValTagList(  attrList[i].first ) ;
      for (unsigned int i = 0 ; i < v.size() ; i++ )
	cout << v[i].first  << " - " << v[i].second << " ;   " << flush ;
    }
      break;
    case JobStatus::INTLIST_T    :{
      std::vector<int> v = stat.getValIntList(attrList[i].first);
      for(unsigned int j=0; j < v.size(); j++)
	cout << "  " << v[j]  << flush ;
      cout << endl<<flush;
    }
      break;
    case JobStatus::STRLIST_T    :{
      std::vector<std::string> v = stat.getValStringList(attrList[i].first);
      for(unsigned int j=0; j < v.size(); j++)
	cout << v[j] ;
      cout << endl<<flush;
    }
      break ;
    default : /* something is wrong */
      break;
    }
  }
  cout << endl<<flush;
} // printStatus



int main (int argc,char *argv[])
{

  cout << "Workload Management API Example " << endl;
  
  try{
    if (argc < 1 ||  strcmp(argv[1],"--help") == 0)  {
      cout << "jobstatus : " << argv[0] 
	   << "  jobid" 
	   << endl;
      return -1;
    }
    std::string strid(argv[1]);
    glite::wmsutils::jobid::JobId jid(strid);
    glite::wmsui::api::Job   job(jid);
    
    // Now we check the status of the submitted job. We check it 
    // until it reaches DONE (6), CLEARED (7), ABORTED (8), CANCELLED (9)
    //
    JobStatus status;
    int state = 0;
    do {
      status = job.getStatus();
      if (state !=  status.status) {
	cout << "\nCurrent job status =  " << status.name() << " " << flush;
	state = status.status;
      } else {
	// Print a small status bar
	cout << "." << flush ;
      }
      sleep(2);
    } while (status.status < 6);

    // Print some detailed error information in case the job did not
    // succeed.
    //
    if ((status.status == 8) || (status.status == 9)) {
      printStatus(status);
      exit(-1);
    }
    return 0;
    
  } catch (std::exception &exc){
    cerr << "\nWMS Error\n";
    cerr <<  exc.what();
  }    
  return -1;
}
