#!/bin/bash

#/**********************************************************************
# *                 III TTTTTTT U     U                                *
# *                  I     T    U     U                                *
# *                  I     T    U     U                                *
# *                  I     T    U     U                                *
# *                 III    T    UUUUUUU                                *
# *                                                                    *
# *  ITU Informatics Institute                                         *
# *  Computational Science & Engineering Dept.                         *
# *  Istanbul / TURKIYE                                                *
# *                                                                    *
# *  By: Ozden AKINCI                                                  *
# *  E-mail: akinci@be.itu.edu.tr                                      *
# *  Date: 10.11.2005                                                  *
# *                                                                    *
# *  Associated files :                                                *
# *       > JDL File  : foam.jdl                                       *
# *       > Script    : openFOAMserial.sh                              *
# *	  > InputFile : test01.tar                                     *
# *       > OutputFile: test01_out.tar                                 *
# *                                                                    *
#**********************************************************************/


if [ $# -lt 1 ]
then
	echo "usage: openFOAM.sh <FILE>"
	exit 1
fi

# $1 argument must be with out extension, the argument will refer to
# the <FILE>.tar
FILE=$1

# HOSTPORT will be used to get GUI, if it is needed.
HOSTPORT=9988

# ROOT is the name of the root directory in the tar file.
# File hierarchy is as $FILE/$ROOT
ROOT=icoFoam

# CASE is the name of the case in the ROOT directory. 
# CASE is also a directory.
# The file hierarchy is as $FILE/$ROOT/$CASE
CASE=cavity

# TARFILE is name of the $1 argument with .tar extension.
# Name of TARFILE must be same with the filename 
# in the InputSandbox attribute of jdl file.
TARFILE=$FILE.tar

# OUTPUTTAR is the output filename of the program. It takes FILE is base, 
# and adds _out.tar extension
OUTPUTTAR=${FILE}_out.tar

echo "TARFILE: $TARFILE"
echo "HOSTPORT: $HOSTPORT"

# OpenFOAM settings 
# The line below is necessary to run an OpenFOAM job.
#################################################
. /opt/OpenFOAM/OpenFOAM-1.2/.OpenFOAM-1.2/bashrc

export RUN=`pwd`
export FOAM_RUN=$RUN
export HOSTPORT=$HOSTPORT

if [ ! -d $FOAM_RUN ]
then
	mkdir -p $FOAM_RUN
fi

# end of OpenFOAM settings
#################################################

echo "*************************************"
echo "Directory: `pwd`/"
echo "*************************************"
echo "list of files"
echo ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>"
ls -la
echo "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<"
echo "Untaring $TARFILE"
tar xvf $TARFILE

# prints the name of the master node
echo "Running on: $HOSTNAME"
echo "*************************************"

#########################################################
# OPENFOAM APPLICATOINS
#########################################################

blockMesh $FOAM_RUN/$FILE/$ROOT $CASE | tee $FOAM_RUN/$FILE/mesh.output$$
$ROOT $FOAM_RUN/$FILE/$ROOT $CASE 
echo "@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@"
echo "Calculation for $ROOT with $CASE has been done"
tar cvf $OUTPUTTAR $FILE
rm -rf $FILE
echo "The output $FILE is archived as $OUTPUTTAR"
echo "The End"
